@@ -18,8 +18,6 @@ wrong the tests might raise AssertionError. I've indicated in comments the
 places where actual behavior differs from the spec.
 """
 
-from __future__ import print_function
-
 
 def assert_has_keys(dictonary, required=None, optional=None):
     if required is None:
@@ -50,16 +48,10 @@ class FakeClient(object):
 
         if body is not None:
             actual = self.client.callstack[pos][2]
+            assert actual == body, "Expected %s; got %s" % (body, actual)
 
-            if isinstance(actual, dict) and isinstance(body, dict):
-                assert sorted(list(actual)) == sorted(list(body))
-            else:
-                assert actual == body, "Expected %(b)s; got %(a)s" % {
-                    'b': body,
-                    'a': actual
-                }
-
-    def assert_called_anytime(self, method, url, body=None):
+    def assert_called_anytime(self, method, url, body=None,
+                              clear_callstack=True):
         """Assert than an API method was called anytime in the test."""
         expected = (method, url)
 
@@ -83,8 +75,8 @@ class FakeClient(object):
                 print("!=")
                 print(body)
                 raise
-
-        self.client.callstack = []
+        if clear_callstack:
+            self.client.callstack = []
 
     def clear_callstack(self):
         self.client.callstack = []
